@@ -27,9 +27,9 @@ build_dfm <- function(x, features,
                       docvars = data.frame(), meta = list(), 
                       class = "dfm", ...) {
     result <- new(class,
-        as(x, "dgCMatrix"),
-        docvars = docvars,
-        meta = make_meta("dfm", inherit = meta, ...)
+                  as(as(as(x, "CsparseMatrix"), "generalMatrix"), "dMatrix"),
+                  docvars = docvars,
+                  meta = make_meta("dfm", inherit = meta, ...)
     )
     # set names directly to avoid NULL
     result@Dimnames <- list(
@@ -250,7 +250,7 @@ build_fcm <- function(x, features1, features2 = NULL,
                       meta = list(), 
                       class = "fcm", ...) {
     result <- new(class,
-                  as(x, "dgCMatrix"),
+                  as(as(as(x, "CsparseMatrix"), "generalMatrix"), "dMatrix"),
                   meta = make_meta("fcm", inherit = meta, ...)
     )
     # set names directly to avoid NULL
